@@ -2,17 +2,21 @@
 #this repository contains the full copyright notices and license terms.
 {
     "name" : "Stock Supply with Week Days",
+    "name_bg_BG" : "Доставка на налиност с дни от седмицата",
     "name_de_DE" : "Lagerverwaltung Bestellwesen nach Wochentagen",
     "name_es_CO" : "Existencias por días de la semana",
     "name_es_ES" : "Suministro de existencias por días de la semana",
     "name_fr_FR" : "Approvisionnement par jours de semaine",
-    "version" : "1.8.0",
+    "version" : "2.2.1",
     "author" : "B2CK",
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
     "description": '''Define the delivery days of the week by suppliers.
 Impact supply dates computations.
 ''',
+    "description_bg_BG": '''Задаване на дните за доставка в седмицата по доставчици
+    - Оказва влияние върху изчисляването на датите
+ ''',
     "description_de_DE": '''Bestellwesen nach Wochentagen
     - Ermöglicht die Definition von Liefertagen pro Lieferant.
     - Wirkt sich auf die Berechnung von Lieferzeitpunkten aus.
@@ -34,9 +38,13 @@ Impacte les calculs de dates de livraisons.
         "purchase.xml",
     ],
     'translation': [
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
+        'locale/cs_CZ.po',
+        'locale/bg_BG.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
